@@ -66,7 +66,8 @@ def openOgler(cls=None, name="test", temp=True, **kwa):
         yield ogler
 
     finally:
-        ogler.close()  # if .temp also clears
+        if ogler:
+            ogler.close()  # if .temp also clears
 
 
 class Ogler():
@@ -257,7 +258,7 @@ class Ogler():
 
     def close(self, clear=False):
         """
-        Close lmdb at .env and if clear or self.temp then remove directory at .path
+        Set .opened to False and remove directory at .path
         Parameters:
            clear is boolean, True means clear directory
         """
